@@ -13,7 +13,7 @@ require Exporter;
 our @ISA       = qw( Exporter );
 our @EXPORT_OK = qw( debug );
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 my $env_prefix = 'DEVEL_SCOPE_';
 my @env_vars_maybe = grep { m|^$env_prefix| } keys %ENV;
@@ -119,11 +119,11 @@ __END__
 
 =head1 NAME
 
-Devel::Scope - Debug Verbosity based on Scope
+Devel::Scope
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =head1 SYNOPSIS
 
@@ -153,7 +153,7 @@ Provide a debug method that outputs conditionally based on the scoping level.
 
     ...
 
-    DEVEL_SCOPE=3 perl foo.pl
+    DEVEL_SCOPE_DEPTH=3 perl foo.pl
 
 =head1 EXPORT
 
